@@ -192,8 +192,17 @@ applet_change_background (PanelApplet               *applet,
 			  GdkPixmap                 *pixmap,
 			  TasklistData              *tasklist)
 {
-	wncklet_change_background (GTK_WIDGET (tasklist->applet), type,
-				   color, pixmap);
+	switch (type) {
+	case PANEL_NO_BACKGROUND:
+		wnck_tasklist_set_button_relief (WNCK_TASKLIST (tasklist->tasklist),
+						 GTK_RELIEF_NORMAL);
+		break;
+	case PANEL_COLOR_BACKGROUND:
+	case PANEL_PIXMAP_BACKGROUND:
+		wnck_tasklist_set_button_relief (WNCK_TASKLIST (tasklist->tasklist),
+						 GTK_RELIEF_NONE);
+		break;
+	}
 }
 
 static void
@@ -705,8 +714,6 @@ window_list_applet_fill (PanelApplet *applet)
 
 	gtk_container_add (GTK_CONTAINER (tasklist->applet), tasklist->tasklist);
 
-	gtk_widget_show (tasklist->applet);
-
 	g_signal_connect (G_OBJECT (tasklist->applet),
 			  "realize",
 			  G_CALLBACK (applet_realized),
@@ -723,6 +730,9 @@ window_list_applet_fill (PanelApplet *applet)
 			  "change_background",
 			  G_CALLBACK (applet_change_background),
 			  tasklist);
+
+	panel_applet_set_background_widget (PANEL_APPLET (tasklist->applet),
+					    GTK_WIDGET (tasklist->applet));
 	
 	panel_applet_setup_menu_from_file (PANEL_APPLET (tasklist->applet),
 					   NULL,
@@ -741,6 +751,8 @@ window_list_applet_fill (PanelApplet *applet)
 					      "hidden", "1",
 					      NULL);
 	}
+
+	gtk_widget_show (tasklist->applet);
 	
 	return TRUE;
 }
