@@ -7,10 +7,13 @@
 G_BEGIN_DECLS
 
 GtkWidget *panel_edit_dentry   (const char *loc,
-				const char *dir);
+				const char *dir,
+				GdkScreen  *screen);
 GtkWidget *panel_edit_direntry (const char *dir,
-				const char *dir_name);
-GtkWidget *panel_new_launcher  (const char *item_loc);
+				const char *dir_name,
+				GdkScreen  *screen);
+GtkWidget *panel_new_launcher  (const char *item_loc,
+				GdkScreen  *screen);
 
 G_END_DECLS
 
